package mechanism

import (
	"fmt"

	"github.com/guonaihong/gout"
	"gogs.uu.mdfitnesscao.com/hys/sdk"
	"gogs.uu.mdfitnesscao.com/hys/sdk/response"
)

// 获取机构列表
func GetAuthMechanism(mechanismId, staffId string) (*sdk.BaseResponse[sdk.DetailResponse[*sdk.AuthMechanism]], *response.ErrCode) {
	var resp *sdk.BaseResponse[sdk.DetailResponse[*sdk.AuthMechanism]]
	resp, err := postReq[*sdk.BaseResponse[sdk.DetailResponse[*sdk.AuthMechanism]]]("/mechanismService/openapi/mechanism/getAuthMechanism", gout.H{
		"mechanismId": mechanismId,
		"staffId":     staffId,
	})
	if err != nil {
		return nil, &response.ErrCode{
			Code: response.PLATFORM_ERROR,
			Msg:  err.Error(),
		}
	}
	if resp == nil {
		return nil, response.ErrPlatform
	}
	if resp.Code != 200 {
		return nil, &response.ErrCode{
			Code: resp.Code,
			Msg:  resp.Message,
		}
	}
	return resp, nil
}

// 获取机构列表
func ListMechanism(ids []string) (*sdk.BaseResponse[sdk.ListResponse[*sdk.Mechanism]], *response.ErrCode) {
	var resp *sdk.BaseResponse[sdk.ListResponse[*sdk.Mechanism]]
	resp, err := postReq[*sdk.BaseResponse[sdk.ListResponse[*sdk.Mechanism]]]("/mechanismService/openapi/mechanism/listByIds", gout.H{
		"mechanismIds": ids,
	})
	if err != nil {
		return nil, &response.ErrCode{
			Code: response.PLATFORM_ERROR,
			Msg:  err.Error(),
		}
	}
	if resp == nil {
		return nil, response.ErrPlatform
	}
	if resp.Code != 200 {
		return nil, &response.ErrCode{
			Code: resp.Code,
			Msg:  resp.Message,
		}
	}
	return resp, nil
}

// 获取机构列表
func ListMechanismList() (*sdk.BaseResponse[sdk.ListResponse[*sdk.Mechanism]], *response.ErrCode) {
	var resp *sdk.BaseResponse[sdk.ListResponse[*sdk.Mechanism]]
	resp, err := postReq[*sdk.BaseResponse[sdk.ListResponse[*sdk.Mechanism]]]("/mechanismService/openapi/mechanism/list", gout.H{})
	if err != nil {
		return nil, &response.ErrCode{
			Code: response.PLATFORM_ERROR,
			Msg:  err.Error(),
		}
	}
	if resp == nil {
		return nil, response.ErrPlatform
	}
	if resp.Code != 200 {
		return nil, &response.ErrCode{
			Code: resp.Code,
			Msg:  resp.Message,
		}
	}
	return resp, nil
}

// 通过AppKey获取机构信息
func DetailByAppKey(appKey string) (*sdk.BaseResponse[sdk.DetailResponse[*sdk.Mechanism]], *response.ErrCode) {
	var resp *sdk.BaseResponse[sdk.DetailResponse[*sdk.Mechanism]]
	resp, err := postReq[*sdk.BaseResponse[sdk.DetailResponse[*sdk.Mechanism]]]("/mechanismService/openapi/mechanism/detailByAppKey", gout.H{
		"appKey": appKey,
	})
	if err != nil {
		return nil, &response.ErrCode{
			Code: response.PLATFORM_ERROR,
			Msg:  err.Error(),
		}
	}
	if resp == nil {
		return nil, response.ErrPlatform
	}
	if resp.Code != 200 {
		return nil, &response.ErrCode{
			Code: resp.Code,
			Msg:  resp.Message,
		}
	}
	return resp, nil
}

// postReq 发送post请求
func postReq[T any](path string, data gout.H) (T, error) {
	var res T
	fmt.Println(sdk.GetConfig())
	// 检查配置
	if sdk.GetConfig().ApiDomain == "" {
		return res, fmt.Errorf("请先配置API域名")
	}
	url := fmt.Sprintf("%s%s", sdk.GetConfig().ApiDomain, path)
	fmt.Println("请求地址 ===>", url)
	err := gout.POST(url).Debug(sdk.GetConfig().AppDebug).
		SetHeader(gout.H{}).
		SetJSON(data).
		BindJSON(&res).
		Do()
	if err != nil {
		fmt.Println("请求失败: ", err)
		return res, err
	}
	return res, nil
}
